@@ -22,12 +22,7 @@
 
 #include <QDir>
 
-#ifdef Q_WS_HILDON
 const QString POMODORO_FILE_ALERT = "/opt/pomodoro/alarm.wav";
-#else // Q_WS_HILDON
-const QString POMODORO_FILE_ALERT = "/Users/Sakari/Projects/pomodoro.git/data/alarm.wav";
-#endif // Q_WS_HILDON
-
 const QString POMODORO_FILE_MODEL = QDir::homePath() + '/' + ".pomodoro.data";
 const QString POMODORO_VERSION = "0.1";
 
